#ifndef SWIPECOUNTER_H
#define SWIPECOUNTER_H

#include <QFrame>
#include <QtGui/qlabel.h>
#include <QtGui/qinputdialog.h>
#include <QtGui/qpainter.h>
#include <QtGui/qdialog.h>
#include <QVBoxLayout>
#include <GConfItem>
#include <QSettings>
class SwipeCounter : public QWidget
{
    Q_OBJECT

public:

    SwipeCounter();

public slots:
    void showSettingsDialog();
    void desktopChanged();
private:
    QLabel *count;
    QLabel *distance;
    GConfItem *conf;
    int swipes;
    double dist;
    QSettings set;

};


#endif // SWIPECOUNTER_H
